@@ -1,3 +1,4 @@
+import inspect
 from copy import copy
 from typing import TYPE_CHECKING, Dict, List, Optional, Union, cast
 
@@ -67,6 +68,23 @@ class Controller:
 
         self.path = normalize_path(self.path or "/")
         self.owner = owner
+        self._unbind_lifecycle_hook_functions()
+
+    def _unbind_lifecycle_hook_functions(self) -> None:
+        """
+        Functions assigned to class variables will be bound as instance methods on instantiation of the controller.
+        Left unchecked, this results in a `TypeError` when the handlers are called as any function satisfying the type
+        annotation of the lifecycle hook attributes can only receive a single positional argument, but will receive two
+        positional arguments if called as an instance method (`self` and the hook argument)`.
+
+        Overwrites the bound method with the original function.
+        """
+        for hook_key in ("after_request", "after_response", "before_request"):
+            hook_class_var = getattr(type(self), hook_key, None)
+            if not hook_class_var:
+                continue
+            if inspect.isfunction(hook_class_var):
+                setattr(self, hook_key, hook_class_var)
 
     def get_route_handlers(self) -> List[BaseRouteHandler]:
         """
