@@ -32,6 +32,7 @@ if TYPE_CHECKING:
     from starlite.router import Router
     from starlite.types import (
         AfterRequestHandler,
+        AfterResponseHandler,
         BeforeRequestHandler,
         ExceptionHandler,
         Guard,
@@ -119,17 +120,18 @@ def create_test_client(
     ],
     *,
     after_request: Optional["AfterRequestHandler"] = None,
+    after_response: Optional["AfterResponseHandler"] = None,
     allowed_hosts: Optional[List[str]] = None,
     backend: str = "asyncio",
     backend_options: Optional[Dict[str, Any]] = None,
     base_url: str = "http://testserver",
     before_request: Optional["BeforeRequestHandler"] = None,
     cache_config: "CacheConfig" = DEFAULT_CACHE_CONFIG,
+    compression_config: Optional["CompressionConfig"] = None,
     cors_config: Optional["CORSConfig"] = None,
     dependencies: Optional[Dict[str, "Provide"]] = None,
     exception_handlers: Optional[Dict[Union[int, "Type[Exception]"], "ExceptionHandler"]] = None,
     guards: Optional[List["Guard"]] = None,
-    compression_config: Optional["CompressionConfig"] = None,
     middleware: Optional[List["Middleware"]] = None,
     on_shutdown: Optional[List["LifeCycleHandler"]] = None,
     on_startup: Optional[List["LifeCycleHandler"]] = None,
@@ -145,14 +147,15 @@ def create_test_client(
     return TestClient(
         app=Starlite(
             after_request=after_request,
+            after_response=after_response,
             allowed_hosts=allowed_hosts,
             before_request=before_request,
             cache_config=cache_config,
+            compression_config=compression_config,
             cors_config=cors_config,
             dependencies=dependencies,
             exception_handlers=exception_handlers,
             guards=guards,
-            compression_config=compression_config,
             middleware=middleware,
             on_shutdown=on_shutdown,
             on_startup=on_startup,
